@@ -3,7 +3,7 @@
 # Filename: CleanAll.sh
 # Function: Clean GBase 8s Auto Install.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.13   update date: 2025-06-09
+# Version : 1.4.15   update date: 2025-08-05
 ##################################################################
 ##### Define Parameter
 ##### Get Parameter
@@ -38,7 +38,7 @@ if [ $? -gt 0 ];then
     exit 2
 fi
 
-if [ -f /${USER_NAME}TMP/.infxdirs ]; then
+if [ -f /${USER_UPPER}TMP/.infxdirs ]; then
   INSTALL_DIR=$(head -n 1 /${USER_UPPER}TMP/.infxdirs)
 else
   echo ".infxdirs not found !"
